package org.apache.bcel.generic;

import java.io.DataOutputStream;
import java.io.IOException;
import org.apache.bcel.util.ByteSequence;

/* loaded from: org_apache_bcel_generic.jar:org/apache/bcel/generic/Select.class */
public abstract class Select extends BranchInstruction implements VariableLengthInstruction, StackConsumer, StackProducer {

    @Deprecated
    protected int[] match;

    @Deprecated
    protected int[] indices;

    @Deprecated
    protected InstructionHandle[] targets;

    @Deprecated
    protected int fixed_length;

    @Deprecated
    protected int match_length;

    @Deprecated
    protected int padding;

    /* JADX INFO: Access modifiers changed from: package-private */
    public Select() {
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public Select(short opcode, int[] match, InstructionHandle[] targets, InstructionHandle defaultTarget) {
        super(opcode, null);
        this.match = match;
        this.targets = targets;
        setTarget(defaultTarget);
        for (InstructionHandle target2 : targets) {
            notifyTarget(null, target2, this);
        }
        int length = match.length;
        this.match_length = length;
        if (length != targets.length) {
            throw new ClassGenException("Match and target array have not the same length: Match length: " + match.length + " Target length: " + targets.length);
        }
        this.indices = new int[this.match_length];
    }

    protected Object clone() throws CloneNotSupportedException {
        Select copy = (Select) super.clone();
        copy.match = (int[]) this.match.clone();
        copy.indices = (int[]) this.indices.clone();
        copy.targets = (InstructionHandle[]) this.targets.clone();
        return copy;
    }

    @Override // org.apache.bcel.generic.BranchInstruction, org.apache.bcel.generic.InstructionTargeter
    public boolean containsTarget(InstructionHandle ih) {
        if (super.getTarget() == ih) {
            return true;
        }
        for (InstructionHandle target2 : this.targets) {
            if (target2 == ih) {
                return true;
            }
        }
        return false;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    @Override // org.apache.bcel.generic.BranchInstruction, org.apache.bcel.generic.Instruction
    public void dispose() {
        super.dispose();
        for (InstructionHandle target2 : this.targets) {
            target2.removeTargeter(this);
        }
    }

    @Override // org.apache.bcel.generic.BranchInstruction, org.apache.bcel.generic.Instruction
    public void dump(DataOutputStream out) throws IOException {
        out.writeByte(super.getOpcode());
        for (int i = 0; i < this.padding; i++) {
            out.writeByte(0);
        }
        super.setIndex(getTargetOffset());
        out.writeInt(super.getIndex());
    }

    final int getFixedLength() {
        return this.fixed_length;
    }

    public int[] getIndices() {
        return this.indices;
    }

    final int getIndices(int index) {
        return this.indices[index];
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public final int getMatch(int index) {
        return this.match[index];
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public final int getMatchLength() {
        return this.match_length;
    }

    public int[] getMatchs() {
        return this.match;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public final int getPadding() {
        return this.padding;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public final InstructionHandle getTarget(int index) {
        return this.targets[index];
    }

    public InstructionHandle[] getTargets() {
        return this.targets;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // org.apache.bcel.generic.BranchInstruction, org.apache.bcel.generic.Instruction
    public void initFromFile(ByteSequence bytes, boolean wide) throws IOException {
        this.padding = (4 - (bytes.getIndex() % 4)) % 4;
        for (int i = 0; i < this.padding; i++) {
            bytes.readByte();
        }
        super.setIndex(bytes.readInt());
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public final void setFixedLength(int fixedLength) {
        this.fixed_length = fixedLength;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public final int setIndices(int i, int value) {
        this.indices[i] = value;
        return value;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public final void setIndices(int[] array) {
        this.indices = array;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public final void setMatch(int index, int value) {
        this.match[index] = value;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public final int setMatchLength(int matchLength) {
        this.match_length = matchLength;
        return matchLength;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public final void setMatches(int[] array) {
        this.match = array;
    }

    public void setTarget(int i, InstructionHandle target) {
        notifyTarget(this.targets[i], target, this);
        this.targets[i] = target;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public final void setTargets(InstructionHandle[] array) {
        this.targets = array;
    }

    @Override // org.apache.bcel.generic.BranchInstruction, org.apache.bcel.generic.Instruction
    public String toString(boolean verbose) {
        StringBuilder buf = new StringBuilder(super.toString(verbose));
        if (verbose) {
            for (int i = 0; i < this.match_length; i++) {
                String s = "null";
                if (this.targets[i] != null) {
                    s = this.targets[i].getInstruction().toString();
                }
                buf.append("(").append(this.match[i]).append(", ").append(s).append(" = {").append(this.indices[i]).append("})");
            }
        } else {
            buf.append(" ...");
        }
        return buf.toString();
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // org.apache.bcel.generic.BranchInstruction
    public int updatePosition(int offset, int maxOffset) {
        setPosition(getPosition() + offset);
        short oldLength = (short) super.getLength();
        this.padding = (4 - ((getPosition() + 1) % 4)) % 4;
        super.setLength((short) (this.fixed_length + this.padding));
        return super.getLength() - oldLength;
    }

    @Override // org.apache.bcel.generic.BranchInstruction, org.apache.bcel.generic.InstructionTargeter
    public void updateTarget(InstructionHandle oldIh, InstructionHandle newIh) {
        boolean targeted = false;
        if (super.getTarget() == oldIh) {
            targeted = true;
            setTarget(newIh);
        }
        for (int i = 0; i < this.targets.length; i++) {
            if (this.targets[i] == oldIh) {
                targeted = true;
                setTarget(i, newIh);
            }
        }
        if (!targeted) {
            throw new ClassGenException("Not targeting " + oldIh);
        }
    }
}
